==> localnews-admin-service-3.8.0-sources.jar: com/bxm/localnews/admin/service/im/IMService.java <==
package com.bxm.localnews.admin.service.im;

import com.bxm.localnews.admin.dto.im.BlockUserDTO;
import com.bxm.localnews.admin.dto.im.ChatRoomMessageDTO;
import com.bxm.localnews.admin.param.BatchMessageParam;
import com.bxm.localnews.admin.param.ChatRoomQueryParam;
import com.bxm.localnews.admin.param.ImMessageQueryParam;
import com.bxm.localnews.admin.vo.im.HistoryChatBean;
import com.bxm.localnews.admin.vo.im.ImMessageBean;
import com.bxm.newidea.component.vo.PageWarper;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * 即时通讯相关服务
 * @author liujia
 */
public interface IMService {
    /**
     * 查询聊天记录
     * @param param 查询参数
     * @return 聊天记录列表
     */
    List<ImMessageBean> query(ImMessageQueryParam param);

    /**
     * 查询用户的历史聊天记录
     * @param userId 用户ID
     * @return 历史聊天对象
     */
    List<HistoryChatBean> queryHistory(Long userId);

    void getVoiceByContent(String content, HttpServletResponse response);

    PageWarper<ChatRoomMessageDTO> queryChatRoomRecord(ChatRoomQueryParam param);

    Boolean createChatRoom(String areaCode);

    List<BlockUserDTO> queryChatRoomBlockUser(String chatRoomId);

    /**
     * 聊天室用户禁言
     * @param chatRoomId
     * @param userId
     * @param id
     * @return
     */
    Boolean blockChatRoomUser(String chatRoomId, Date time, Long userId, Long id);

    /**
     * 解除聊天室禁言
     * @param chatRoomId
     * @param userId
     * @param id
     * @return
     */
    Boolean unBlockChatRoomUser(String chatRoomId, Long userId, Long id);

    Boolean sendBatchMessage(BatchMessageParam batchMessageParam);

    /**
     * 清除马甲号与真实用户聊天记录的未回复数量
     * @param virtualUserId
     * @param realUserId
     * @return
     */
    Boolean clearChatRecord(Long virtualUserId, Long realUserId);
}

==> localnews-admin-service-3.12.0-sources.jar: com/bxm/localnews/admin/service/im/IMService.java <==
package com.bxm.localnews.admin.service.im;

import com.bxm.localnews.admin.dto.im.BlockUserDTO;
import com.bxm.localnews.admin.dto.im.ChatRoomMessageDTO;
import com.bxm.localnews.admin.param.BatchMessageParam;
import com.bxm.localnews.admin.param.ChatRoomQueryParam;
import com.bxm.localnews.admin.param.ImHistoryParam;
import com.bxm.localnews.admin.param.ImMessageQueryParam;
import com.bxm.localnews.admin.vo.im.HistoryChatBean;
import com.bxm.localnews.admin.vo.im.ImMessageBean;
import com.bxm.newidea.component.vo.PageWarper;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * 即时通讯相关服务
 * @author liujia
 */
public interface IMService {
    /**
     * 查询聊天记录
     * @param param 查询参数
     * @return 聊天记录列表
     */
    List<ImMessageBean> query(ImMessageQueryParam param);

    /**
     * 查询用户的历史聊天记录
     * @param param param
     * @return 历史聊天对象
     */
    List<HistoryChatBean> queryHistory(ImHistoryParam param);

    void getVoiceByContent(String content, HttpServletResponse response);

    PageWarper<ChatRoomMessageDTO> queryChatRoomRecord(ChatRoomQueryParam param);

    Boolean createChatRoom(String areaCode);

    List<BlockUserDTO> queryChatRoomBlockUser(String chatRoomId);

    /**
     * 聊天室用户禁言
     * @param chatRoomId
     * @param userId
     * @param id
     * @return
     */
    Boolean blockChatRoomUser(String chatRoomId, Date time, Long userId, Long id);

    /**
     * 解除聊天室禁言
     * @param chatRoomId
     * @param userId
     * @param id
     * @return
     */
    Boolean unBlockChatRoomUser(String chatRoomId, Long userId, Long id);

    Boolean sendBatchMessage(BatchMessageParam batchMessageParam);

    /**
     * 清除马甲号与真实用户聊天记录的未回复数量
     * @param virtualUserId
     * @param realUserId
     * @return
     */
    Boolean clearChatRecord(Long virtualUserId, Long realUserId);
}
